"use client"

import LoadingItem from "@/components/loading-item"
import { TryAgain } from "@/components/try-again"
import { Card } from "@/components/ui/card"
import { UserNotFound } from "@/components/user-not-found"
import { usePathname } from "next/navigation"
import { useUser } from "../hooks/use-user"
import { ProfileUserInfo } from "./profile-user-info"

export const Profile = ({ children }: { children: React.ReactNode }) => {
    const pathname = usePathname()
    const username = pathname?.split("/")[1] || ""
    // TODO: Fix this client / server side rendering issue
    const { data: user, isLoading, isError } = useUser(username)

    if (isLoading) {
        return (
            <>
                <LoadingItem />
            </>
        )
    }

    if (isError) {
        return (
            <>
                <TryAgain />
            </>
        )
    }

    if (!isLoading && !isError && !user) {
        return (
            <>
                <UserNotFound />
            </>
        )
    }

    return (
        <Card className="overflow-hidden h-full w-full">
            {/* <ProfileUserInfo user={user} /> */}
            <div>{children}</div>
        </Card>
    )
}
